/**********************************************************************
 * imap4_write .c                                        September 1999
 * Horms                                             horms@vergenet.net
 *
 * Subroutines to write IMAP4 protocol output
 *
 * Licenced under the terms of the GNU GPL
 *
 **********************************************************************/

#include "imap4_write.h"


/**********************************************************************
 * imap4_write
 * Display an ok message
 * Pre: fd: file descriptor to write to
 *      tag: tag to reply with
 *      type: type of message, IMAP4_OK, IMAP4_NO or IMAP4_BAD
 *      string: mesage to display
 * Return 1 on success
 *        0 otherwise
 **********************************************************************/

int imap4_write(
  const int fd, 
  const token_t *tag, 
  const char *type, 
  const char *string
){
  char *tag_string;
  int free_tag_string;
  

  if(tag==NULL){
    tag_string=IMAP4_UNTAGED;
    free_tag_string=0;
  }
  else {
    if((tag_string=token_to_string(tag, tag_string))==NULL){
      syslog(LOG_WARNING, "imap4_in_tagged_ok: token_to_string");
      return(-1);
    }
    free_tag_string=1;
  }

  if(write_str(fd, 5, tag_string, " ", type, " ", string)<0){
    syslog(LOG_WARNING, "imap4_write: write_strings");
    return(-1);
  }
  
  if(free_tag_string){
    str_free(&tag_string);
  }
  return(0);
}
